<?php
/*
Purpose: To launch an FMP URL from a PHP script. In other words, to make an FMP URL "clickable" from any browser and email client.
         Some email clients don't make FMP URLs a clickable link because they don't recognize the FMP protocol.
         By turning the FMP URL into an HTTP URL, you gain the clickability of an HTTP URL while maintaining the functionality
         of an FMP URL.
Parameters:
	host = (Required) The URL or IP of the FileMaker Server that's hosting the file you want to call
	database = (Optional) The name of the FileMaker file you want to call. Doesn't need an extension.
	script = (Optional) The name of the script you want to call in the FileMaker file.
	param = (Optional) The script parameter to pass to the script.
	$var1 = (Optional) Any variable you want to pass to the script. You can name the variables whatever you want 
        	and you can pass as many as you want.
	$var2
	$var3
	and so on

See FileMaker's "Opening shared databases remotely using a URL" page in FileMaker Pro's Help for more information.

2014-03-15, JH, Created script.
*/

// Determine the request method (GET or POST)
switch($_SERVER['REQUEST_METHOD'])
{
	case 'GET': $theRequest = $_GET; break;
	case 'POST': $theRequest = $_POST; break;
	default: $theRequest = "Unknown";
}
if( $theRequest == 'Unknown' ){
	echo "ERROR: Unknown request method. Must be a GET or POST.";
	exit;
}

// Grab request parameters
$host = ( array_key_exists( 'host', $theRequest ) ? $theRequest["host"] : '' ) ;
$database = ( array_key_exists( 'database', $theRequest ) ? $theRequest["database"] : '' ) ;
$script = ( array_key_exists( 'script', $theRequest ) ? $theRequest["script"] : '' ) ;
$param = ( array_key_exists( 'param', $theRequest ) ? $theRequest["param"] : '' ) ;
// Assume remaining parameters are script variables
$scriptVars = array( );
while( list( $key, $val ) = each( $theRequest ) ){
	if( $key == 'host' | $key == 'database' | $key == 'script' | $key == 'param' ){
		'';
	}
	else{
		// Add a leading $ to the key, to make it an FM script variable (if it doesn't already have one)
		$scriptVarName = (substr( $key, 0, 1 ) != '$' ? '$' : '' ) . $key;
		$scriptVars[ $scriptVarName ] = $val;
	}
}

// Validate parameters
// Host must be supplied
if( $host == '' )
{
	echo "ERROR: Please specify a host.";
	exit;
}

// Synthesize the FMP URL
$fmpURL = "FMP://$host";
$fmpURL = $fmpURL . ($database != '' ? "/" . urlencode( $database ) : '' );
if( $script != '' ){
	$fmpURL = $fmpURL . ($script != '' ? "?script=" . rawurlencode( $script ) : '' );
	$fmpURL = $fmpURL . ($param != '' ? "&param=" . rawurlencode( $param ) : '' );
	if( ! empty( $scriptVars ) ){
		while( list( $key, $val ) = each( $scriptVars ) ){
			$fmpURL = $fmpURL . "&$key=" . rawurlencode( $val ) ;
		}
	}
}

// Launch FMP URL
header("Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0");
header("Pragma: no-cache");
header("Content-type: text/html");
header("Location: $fmpURL");
?>